@@ -220,14 +220,44 @@ defaultPostgresConf extra = defaultConfig <> mempty
     }
   }
 
--- | The same as 'defaultConfig' but all the handles are set to @/dev/null@.
---   See 'silentProcessConfig' as well.
---
---   @since 1.12.0.0
+
+--   @since 1.14.0.0
+silentPostgresConfig :: [String]
+silentPostgresConfig =
+  [ "shared_buffers = 12MB"
+  , "fsync = off"
+  , "synchronous_commit = off"
+  , "full_page_writes = off"
+  , "log_min_messages = PANIC"
+  , "log_min_error_statement = PANIC"
+  , "log_statement = none"
+  , "client_min_messages = ERROR"
+  ]
+
+{-|
+The similar to 'defaultConfig' but all the handles are set to @/dev/null@.
+and uses a @postgresql.conf@ which disables logging:
+
+ @
+   shared_buffers = 12MB
+   fsync = off
+   synchronous_commit = off
+   full_page_writes = off
+   log_min_messages = PANIC
+   log_min_error_statement = PANIC
+   log_statement = none
+   client_min_messages = ERROR
+ @
+
+See 'silentProcessConfig' as well.
+
+@since 1.14.0.0
+-}
 silentConfig :: Config
 silentConfig = defaultConfig <> mempty
   { plan = mempty
-    { initDbConfig = pure silentProcessConfig
+    { postgresConfigFile = silentPostgresConfig
+    , initDbConfig = pure silentProcessConfig
     , postgresPlan = mempty
         { postgresConfig = silentProcessConfig
         }
@@ -537,11 +567,12 @@ startNewDbConfig
   --   connection options
   --   is used as the template for the @generated@ 'ProcessConfig'.
   -> IO (Either StartError DB)
-startNewDbConfig extra db = try $ do
+startNewDbConfig extra@ProcessConfig{..} db = try $ do
   stdGen <- getStdGen
   let oldOptions@Client.Options {..} = toConnectionOptions db
       theDbName = fromMaybe "postgres" $ getLast dbname
-      newDbName = take 32 $ randomRs ('a', 'z') stdGen
+      newDbName = fromMaybe (take 32 $ randomRs ('a', 'z') stdGen) $
+        Map.lookup 0 $ indexBased commandLine
       newOptions = oldOptions
         { Client.dbname = pure newDbName
         }
@@ -563,6 +594,7 @@ startNewDbConfig extra db = try $ do
         }
   envs <- getEnvironment
   final <- case completeProcessConfig envs combined of
+    -- Failure case does not look possible
     Left errs -> throwIO $ CompleteProcessConfigFailed (show $ pretty combined) errs
     Right x -> pure x
   terminateConnections oldOptions
