@@ -327,7 +327,12 @@ rmDirIgnoreErrors mainDir = do
   let ignoreDirIsMissing e
         | isDoesNotExistError e = return ()
         | otherwise = throwIO e
-  removeDirectoryRecursive mainDir `catch` ignoreDirIsMissing
+  -- I'm trying to prevent new files getting added
+  -- to the dir as I am deleting the files.
+  let newName = mainDir <> "_removing"
+  handle ignoreDirIsMissing $ uninterruptibleMask_ $ do
+    renameDirectory mainDir newName
+    removeDirectoryRecursive newName
 
 -- | Either remove a 'CTemporary' directory or do nothing to a 'CPermanent'
 -- one.
